# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
from abc import abstractproperty
from .base_index_mark import BaseIndexMark as BaseIndexMark_bbb30bcb

class DocumentIndexMark(BaseIndexMark_bbb30bcb):
    """
    Service Class

    is a TextRange which is explicitly marked as an index entry for a DocumentIndex.

    See Also:
        `API DocumentIndexMark <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1DocumentIndexMark.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.DocumentIndexMark'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def IsMainEntry(self) -> bool:
        """
        determines if this entry is a main entry.
        
        In a document index this entry will be emphasized by assigning a character style to it.
        """
        ...

    @abstractproperty
    def PrimaryKey(self) -> str:
        """
        contains the primary key of the index entry.
        
        It is used to build a hierarchical document index.
        """
        ...

    @abstractproperty
    def SecondaryKey(self) -> str:
        """
        contains the secondary key of the index entry.
        
        It is used to build a hierarchical document index.
        """
        ...


__all__ = ['DocumentIndexMark']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.document
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from .x_storage_change_listener import XStorageChangeListener as XStorageChangeListener_7c7d1120
    from ..embed.x_storage import XStorage as XStorage_8e460a32

class XStorageBasedDocument(XInterface_8f010a43):
    """
    allows to initialize document with a storage, to store document to a storage, and to set document to be based on provided storage.

    See Also:
        `API XStorageBasedDocument <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1document_1_1XStorageBasedDocument.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.document'
    __ooo_full_ns__: str = 'com.sun.star.document.XStorageBasedDocument'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.document.XStorageBasedDocument'

    @abstractmethod
    def addStorageChangeListener(self, xListener: XStorageChangeListener_7c7d1120) -> None:
        """
        allows to register a listener that will be notified when another storage is set to the document.
        """
        ...
    @abstractmethod
    def getDocumentStorage(self) -> XStorage_8e460a32:
        """
        allows to get the storage the document is based on.

        Raises:
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.uno.Exception: ``Exception``
        """
        ...
    @abstractmethod
    def loadFromStorage(self, xStorage: XStorage_8e460a32, aMediaDescriptor: typing.Tuple[PropertyValue_c9610c73, ...]) -> None:
        """
        lets the document load itself using provided storage.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.frame.DoubleInitializationException: ``DoubleInitializationException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.uno.Exception: ``Exception``
        """
        ...
    @abstractmethod
    def removeStorageChangeListener(self, xListener: XStorageChangeListener_7c7d1120) -> None:
        """
        allows to deregister the listener.
        """
        ...
    @abstractmethod
    def storeToStorage(self, xStorage: XStorage_8e460a32, aMediaDescriptor: typing.Tuple[PropertyValue_c9610c73, ...]) -> None:
        """
        lets the document store itself to the provided storage.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.uno.Exception: ``Exception``
        """
        ...
    @abstractmethod
    def switchToStorage(self, xStorage: XStorage_8e460a32) -> None:
        """
        allows to switch the document to the provided storage.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.uno.Exception: ``Exception``
        """
        ...

__all__ = ['XStorageBasedDocument']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n
import uno
from enum import IntFlag
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class KParseTokens(metaclass=UnoConstMeta, type_name="com.sun.star.i18n.KParseTokens", name_space="com.sun.star.i18n"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.i18n.KParseTokens``"""
        pass

    class KParseTokensEnum(IntFlag, metaclass=ConstEnumMeta, type_name="com.sun.star.i18n.KParseTokens", name_space="com.sun.star.i18n"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.i18n.KParseTokens`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.i18n import KParseTokens as KParseTokens
    else:
        # keep document generators happy
        from ...lo.i18n.k_parse_tokens import KParseTokens as KParseTokens

    class KParseTokensEnum(IntFlag):
        """
        Enum of Const Class KParseTokens

        These constants specify the characters a name or identifier token to be parsed can have.
        
        They are passed to XCharacterClassification.parseAnyToken() and XCharacterClassification.parsePredefinedToken(). They are also set in the ParseResult.StartFlags and ParseResult.ContFlags.
        
        **since**
        
            LibreOffice 6.2
        """
        ASC_UPALPHA = KParseTokens.ASC_UPALPHA
        """
        ASCII A-Z upper alpha.
        """
        ASC_LOALPHA = KParseTokens.ASC_LOALPHA
        """
        ASCII a-z lower alpha.
        """
        ASC_DIGIT = KParseTokens.ASC_DIGIT
        """
        ASCII 0-9 digit.
        """
        ASC_UNDERSCORE = KParseTokens.ASC_UNDERSCORE
        """
        ASCII '_' underscore.
        """
        ASC_DOLLAR = KParseTokens.ASC_DOLLAR
        """
        ASCII '$' dollar.
        """
        ASC_DOT = KParseTokens.ASC_DOT
        """
        ASCII '.' dot/point.
        """
        ASC_COLON = KParseTokens.ASC_COLON
        """
        ASCII ':' colon.
        """
        ASC_CONTROL = KParseTokens.ASC_CONTROL
        """
        Special value to allow control characters (0x00 < char < 0x20)
        """
        ASC_ANY_BUT_CONTROL = KParseTokens.ASC_ANY_BUT_CONTROL
        """
        Special value to allow anything below 128 except control characters.
        
        Not set in ParseResult.
        """
        ASC_OTHER = KParseTokens.ASC_OTHER
        """
        Additional flag set in ParseResult.StartFlags or ParseResult.ContFlags.
        
        Set if none of the above ASC_... (except ASC_ANY_...) single values match an ASCII character parsed.
        """
        UNI_UPALPHA = KParseTokens.UNI_UPALPHA
        """
        Unicode (above 127) upper case letter.
        """
        UNI_LOALPHA = KParseTokens.UNI_LOALPHA
        """
        Unicode (above 127) lower case letter.
        """
        UNI_DIGIT = KParseTokens.UNI_DIGIT
        """
        Unicode (above 127) decimal digit number.
        """
        UNI_TITLE_ALPHA = KParseTokens.UNI_TITLE_ALPHA
        """
        Unicode (above 127) title case letter.
        """
        UNI_MODIFIER_LETTER = KParseTokens.UNI_MODIFIER_LETTER
        """
        Unicode (above 127) modifier letter.
        """
        UNI_OTHER_LETTER = KParseTokens.UNI_OTHER_LETTER
        """
        Unicode (above 127) other letter.
        """
        UNI_LETTER_NUMBER = KParseTokens.UNI_LETTER_NUMBER
        """
        Unicode (above 127) letter number.
        """
        UNI_OTHER_NUMBER = KParseTokens.UNI_OTHER_NUMBER
        """
        Unicode (above 127) other number.
        """
        GROUP_SEPARATOR_IN_NUMBER = KParseTokens.GROUP_SEPARATOR_IN_NUMBER
        """
        If this bit is set in nContCharFlags parameters, the locale's group separator characters in numbers are accepted and ignored/skipped.
        
        Else a group separator in a number ends the current token. A leading group separator is never accepted. If an accepted group separator was encountered in a number (ParseResult.TokenType is KParseType.ASC_NUMBER or KParseType.UNI_NUMBER) this bit is also set in ParseResult.ContFlags.
        
        NOTE: absence of this bit in nContCharFlags changes the default behaviour that in prior releases accepted numbers with group separators but lead to unexpected results when parsing formula expressions where the user entered a (wrong) separator that happened to be the group separator instead of an intended decimal separator. Usually inline numbers in a formula expression do not contain group separators.
        
        **since**
        
            LibreOffice 6.2
        """
        TWO_DOUBLE_QUOTES_BREAK_STRING = KParseTokens.TWO_DOUBLE_QUOTES_BREAK_STRING
        """
        If this bit is set in nContCharFlags parameters and a string enclosed in double quotes is parsed and two consecutive double quotes are encountered, the string is ended.
        
        If this bit is not set, the two double quotes are parsed as one escaped double quote and string parsing continues. The bit is ignored in nStartCharFlags parameters.
        
        Example: \"abc\"\"def\" --> bit not set => abc\"def <br/>\"abc\"\"def\" --> bit set => abc
        """
        UNI_OTHER = KParseTokens.UNI_OTHER
        """
        Additional flag set in ParseResult.StartFlags or ParseResult.ContFlags.
        
        Set if none of the above UNI_... single values match a Unicode character parsed.
        """
        IGNORE_LEADING_WS = KParseTokens.IGNORE_LEADING_WS
        """
        Only valid for nStartCharFlags parameter to CharacterClassification.parseAnyToken() and CharacterClassification.parsePredefinedToken(), ignored on nContCharFlags parameter.
        
        Not set in ParseResult.
        """
        ASC_ALPHA = KParseTokens.ASC_ALPHA
        """
        ASCII a-zA-Z lower or upper alpha.
        """
        ASC_ALNUM = KParseTokens.ASC_ALNUM
        """
        ASCII a-zA-Z0-9 alphanumeric.
        """
        UNI_ALPHA = KParseTokens.UNI_ALPHA
        """
        Unicode (above 127) lower or upper or title case alpha.
        """
        UNI_ALNUM = KParseTokens.UNI_ALNUM
        """
        Unicode (above 127) alphanumeric.
        """
        UNI_LETTER = KParseTokens.UNI_LETTER
        """
        Unicode (above 127) alpha or letter.
        """
        UNI_NUMBER = KParseTokens.UNI_NUMBER
        """
        Unicode (above 127) number.
        """
        ANY_ALPHA = KParseTokens.ANY_ALPHA
        """
        any (ASCII or Unicode) alpha
        """
        ANY_DIGIT = KParseTokens.ANY_DIGIT
        """
        any (ASCII or Unicode) digit
        """
        ANY_ALNUM = KParseTokens.ANY_ALNUM
        """
        any (ASCII or Unicode) alphanumeric
        """
        ANY_LETTER = KParseTokens.ANY_LETTER
        """
        any (ASCII or Unicode) letter
        """
        ANY_NUMBER = KParseTokens.ANY_NUMBER
        """
        any (ASCII or Unicode) number
        """
        ANY_LETTER_OR_NUMBER = KParseTokens.ANY_LETTER_OR_NUMBER
        """
        any (ASCII or Unicode) letter or number
        """

__all__ = ['KParseTokens', 'KParseTokensEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
import typing
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from .text_markup_descriptor import TextMarkupDescriptor as TextMarkupDescriptor_1dcb0f01

class XMultiTextMarkup(ABC):
    """
    provides functionality to apply multiple text markups in one call.
    
    **since**
    
        OOo 3.0.1

    See Also:
        `API XMultiTextMarkup <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1text_1_1XMultiTextMarkup.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.XMultiTextMarkup'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.text.XMultiTextMarkup'

    @abstractmethod
    def commitMultiTextMarkup(self, aMarkups: typing.Tuple[TextMarkupDescriptor_1dcb0f01, ...]) -> None:
        """
        submits multiple new markup ranges.
        
        The main use of this function will probably be for proofreading to allow for setting the markup of all found errors in a sentence in a single call. For this the sequence needs to provide the markups for all errors along with the markup for the identified sentence boundaries. The order of those entries is arbitrary.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XMultiTextMarkup']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
from abc import abstractproperty
from ..beans.property_set import PropertySet as PropertySet_b0e70ba2
from .x_formula_parser import XFormulaParser as XFormulaParser_d54d0cbc
if typing.TYPE_CHECKING:
    from .external_link_info import ExternalLinkInfo as ExternalLinkInfo_f09b0d7e
    from .formula_op_code_map_entry import FormulaOpCodeMapEntry as FormulaOpCodeMapEntry_37da0f61

class FormulaParser(PropertySet_b0e70ba2, XFormulaParser_d54d0cbc):
    """
    Service Class

    
    **since**
    
        OOo 3.1

    See Also:
        `API FormulaParser <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1FormulaParser.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.FormulaParser'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def ExternalLinks(self) -> typing.Tuple[ExternalLinkInfo_f09b0d7e, ...]:
        """
        contains a list of external links referenced in formulas.
        
        Use of this property depends on the FormulaConvention in use. It is relevant only for AddressConvention.XL_OOX to map indices to external documents. The sequence must be in the order of indices used. Note that indices are 1-based, the sequence must start with an empty element.
        
        **since**
        
            OOo 3.1
        """
        ...

    @abstractproperty
    def OpCodeMap(self) -> typing.Tuple[FormulaOpCodeMapEntry_37da0f61, ...]:
        """
        contains the complete mapping of names to op-codes.
        
        Names and symbols not defined here lead to a parser/print error.
        """
        ...

    @abstractproperty
    def CompileEnglish(self) -> bool:
        """
        specifies whether to use English parser and formatter.
        
        Note: When changing this, an already existing OpCodeMap needs to be recreated internally, so for performance reasons set this before setting the OpCodeMap.
        """
        ...

    @abstractproperty
    def FormulaConvention(self) -> int:
        """
        specifies which address reference style convention to use when parsing a formula string.
        """
        ...

    @abstractproperty
    def IgnoreLeadingSpaces(self) -> bool:
        """
        """
        ...

    @abstractproperty
    def ParameterSeparator(self) -> str:
        """
        """
        ...

    @abstractproperty
    def RefConventionChartOOXML(self) -> bool:
        """
        specifies that use special ooxml chart syntax in case of OOXML reference convention, when parsing a formula string.
        
        Special syntax like: [0]!GlobalNamedRange, LocalSheet!LocalNamedRange
        
        **since**
        
            LibreOffice 7.3
        """
        ...


__all__ = ['FormulaParser']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class SystemPointer(metaclass=UnoConstMeta, type_name="com.sun.star.awt.SystemPointer", name_space="com.sun.star.awt"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.awt.SystemPointer``"""
        pass

    class SystemPointerEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.awt.SystemPointer", name_space="com.sun.star.awt"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.awt.SystemPointer`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.awt import SystemPointer as SystemPointer
    else:
        # keep document generators happy
        from ...lo.awt.system_pointer import SystemPointer as SystemPointer

    class SystemPointerEnum(IntEnum):
        """
        Enum of Const Class SystemPointer

        specifies the shape of a mouse pointer.
        """
        ARROW = SystemPointer.ARROW
        """
        specifies the normal arrow-like mouse pointer.
        """
        INVISIBLE = SystemPointer.INVISIBLE
        """
        specifies an invisible mouse pointer.
        """
        WAIT = SystemPointer.WAIT
        """
        specifies a waiting symbol as a mouse pointer (for example hourglass).
        """
        TEXT = SystemPointer.TEXT
        """
        specifies a mouse pointer for text (cursor-like).
        """
        HELP = SystemPointer.HELP
        """
        specifies a mouse pointer for on-line help.
        """
        CROSS = SystemPointer.CROSS
        """
        specifies a cross as a mouse pointer.
        """
        MOVE = SystemPointer.MOVE
        """
        specifies a mouse pointer which symbolizes movement.
        """
        NSIZE = SystemPointer.NSIZE
        """
        specifies a mouse pointer which symbolizes resizing for a top border.
        """
        SSIZE = SystemPointer.SSIZE
        """
        specifies a mouse pointer which symbolizes resizing for a bottom border.
        """
        WSIZE = SystemPointer.WSIZE
        """
        specifies a mouse pointer which symbolizes resizing for a left border.
        """
        ESIZE = SystemPointer.ESIZE
        """
        specifies a mouse pointer which symbolizes resizing for a right border.
        """
        NWSIZE = SystemPointer.NWSIZE
        """
        specifies a mouse pointer which symbolizes resizing for the top-left corner.
        """
        NESIZE = SystemPointer.NESIZE
        """
        specifies a mouse pointer which symbolizes resizing for the top-right corner.
        """
        SWSIZE = SystemPointer.SWSIZE
        """
        specifies a mouse pointer which symbolizes resizing for the bottom-left corner.
        """
        SESIZE = SystemPointer.SESIZE
        """
        specifies a mouse pointer which symbolizes resizing for the bottom-right corner.
        """
        WINDOW_NSIZE = SystemPointer.WINDOW_NSIZE
        """
        specifies a mouse pointer which symbolizes window resizing for a top border.
        """
        WINDOW_SSIZE = SystemPointer.WINDOW_SSIZE
        """
        specifies a mouse pointer which symbolizes window resizing for a bottom border.
        """
        WINDOW_WSIZE = SystemPointer.WINDOW_WSIZE
        """
        specifies a mouse pointer which symbolizes window resizing for a left border.
        """
        WINDOW_ESIZE = SystemPointer.WINDOW_ESIZE
        """
        specifies a mouse pointer which symbolizes window resizing for a right border.
        """
        WINDOW_NWSIZE = SystemPointer.WINDOW_NWSIZE
        """
        specifies a mouse pointer which symbolizes window resizing for the top-left corner.
        """
        WINDOW_NESIZE = SystemPointer.WINDOW_NESIZE
        """
        specifies a mouse pointer which symbolizes window resizing for the top-right corner.
        """
        WINDOW_SWSIZE = SystemPointer.WINDOW_SWSIZE
        """
        specifies a mouse pointer which symbolizes window resizing for the bottom-left corner.
        """
        WINDOW_SESIZE = SystemPointer.WINDOW_SESIZE
        """
        specifies a mouse pointer which symbolizes window resizing for the bottom-right corner.
        """
        HSPLIT = SystemPointer.HSPLIT
        """
        specifies a mouse pointer which symbolizes horizontal splitting.
        """
        VSPLIT = SystemPointer.VSPLIT
        """
        specifies a mouse pointer which symbolizes vertical splitting.
        """
        HSIZEBAR = SystemPointer.HSIZEBAR
        """
        specifies a mouse pointer which symbolizes horizontal resizing.
        """
        VSIZEBAR = SystemPointer.VSIZEBAR
        """
        specifies a mouse pointer which symbolizes vertical resizing.
        """
        HAND = SystemPointer.HAND
        """
        specifies a hand symbol as mouse pointer.
        """
        REFHAND = SystemPointer.REFHAND
        """
        specifies a pointing hand symbol as mouse pointer.
        """
        PEN = SystemPointer.PEN
        """
        specifies a pen symbol as mouse pointer.
        """
        MAGNIFY = SystemPointer.MAGNIFY
        """
        specifies a magnify symbol as mouse pointer.
        """
        FILL = SystemPointer.FILL
        """
        specifies a fill symbol as mouse pointer.
        """
        ROTATE = SystemPointer.ROTATE
        """
        specifies a rotate symbol as mouse pointer.
        """
        HSHEAR = SystemPointer.HSHEAR
        """
        specifies a horizontal shear symbol as mouse pointer.
        """
        VSHEAR = SystemPointer.VSHEAR
        """
        specifies a vertical shear symbol as mouse pointer.
        """
        MIRROR = SystemPointer.MIRROR
        """
        specifies a mirror symbol as mouse pointer.
        """
        CROOK = SystemPointer.CROOK
        """
        specifies a crook symbol as mouse pointer.
        """
        CROP = SystemPointer.CROP
        """
        specifies a crop symbol as mouse pointer.
        """
        MOVEPOINT = SystemPointer.MOVEPOINT
        """
        specifies a mouse pointer which symbolizes moving a point.
        """
        MOVEBEZIERWEIGHT = SystemPointer.MOVEBEZIERWEIGHT
        """
        specifies a mouse pointer which symbolizes moving a Bezier weight.
        """
        MOVEDATA = SystemPointer.MOVEDATA
        """
        specifies a mouse pointer which symbolizes moving data.
        """
        COPYDATA = SystemPointer.COPYDATA
        """
        specifies a mouse pointer which symbolizes copying data.
        """
        LINKDATA = SystemPointer.LINKDATA
        """
        specifies a mouse pointer which symbolizes linking data.
        """
        MOVEDATALINK = SystemPointer.MOVEDATALINK
        """
        specifies a mouse pointer which symbolizes moving a data link.
        """
        COPYDATALINK = SystemPointer.COPYDATALINK
        """
        specifies a mouse pointer which symbolizes copying a data link.
        """
        MOVEFILE = SystemPointer.MOVEFILE
        """
        specifies a mouse pointer which symbolizes moving a file.
        """
        COPYFILE = SystemPointer.COPYFILE
        """
        specifies a mouse pointer which symbolizes copying a file.
        """
        LINKFILE = SystemPointer.LINKFILE
        """
        specifies a mouse pointer which symbolizes linking a file.
        """
        MOVEFILELINK = SystemPointer.MOVEFILELINK
        """
        specifies a mouse pointer which symbolizes moving a file link.
        """
        COPYFILELINK = SystemPointer.COPYFILELINK
        """
        specifies a mouse pointer which symbolizes copying a file link.
        """
        MOVEFILES = SystemPointer.MOVEFILES
        """
        specifies a mouse pointer which symbolizes moving multiple files.
        """
        COPYFILES = SystemPointer.COPYFILES
        """
        specifies a mouse pointer which symbolizes copying multiple files.
        """
        NOTALLOWED = SystemPointer.NOTALLOWED
        """
        specifies a mouse pointer which symbolizes \"not allowed\".
        """
        DRAW_LINE = SystemPointer.DRAW_LINE
        """
        specifies a mouse pointer which symbolizes drawing a line.
        """
        DRAW_RECT = SystemPointer.DRAW_RECT
        """
        specifies a mouse pointer which symbolizes drawing a rectangle.
        """
        DRAW_POLYGON = SystemPointer.DRAW_POLYGON
        """
        specifies a mouse pointer which symbolizes drawing a polygon.
        """
        DRAW_BEZIER = SystemPointer.DRAW_BEZIER
        """
        specifies a mouse pointer which symbolizes drawing a Bezier.
        """
        DRAW_ARC = SystemPointer.DRAW_ARC
        """
        specifies a mouse pointer which symbolizes drawing an arc.
        """
        DRAW_PIE = SystemPointer.DRAW_PIE
        """
        specifies a mouse pointer which symbolizes drawing a pie.
        """
        DRAW_CIRCLECUT = SystemPointer.DRAW_CIRCLECUT
        """
        specifies a mouse pointer which symbolizes drawing a circle cut.
        """
        DRAW_ELLIPSE = SystemPointer.DRAW_ELLIPSE
        """
        specifies a mouse pointer which symbolizes drawing an ellipse.
        """
        DRAW_FREEHAND = SystemPointer.DRAW_FREEHAND
        """
        specifies a mouse pointer which symbolizes drawing free handed.
        """
        DRAW_CONNECT = SystemPointer.DRAW_CONNECT
        """
        specifies a mouse pointer which symbolizes drawing a connector.
        """
        DRAW_TEXT = SystemPointer.DRAW_TEXT
        """
        specifies a mouse pointer which symbolizes drawing text.
        """
        DRAW_CAPTION = SystemPointer.DRAW_CAPTION
        """
        specifies a mouse pointer which symbolizes drawing a text caption.
        """
        CHART = SystemPointer.CHART
        """
        specifies a mouse pointer which symbolizes a chart.
        """
        DETECTIVE = SystemPointer.DETECTIVE
        """
        specifies a mouse pointer which symbolizes a detective.
        """
        PIVOT_COL = SystemPointer.PIVOT_COL
        """
        specifies a mouse pointer which symbolizes a pivot column.
        """
        PIVOT_ROW = SystemPointer.PIVOT_ROW
        """
        specifies a mouse pointer which symbolizes a pivot row.
        """
        PIVOT_FIELD = SystemPointer.PIVOT_FIELD
        """
        specifies a mouse pointer which symbolizes a pivot field.
        """
        CHAIN = SystemPointer.CHAIN
        """
        specifies a mouse pointer which symbolizes a chain.
        """
        CHAIN_NOTALLOWED = SystemPointer.CHAIN_NOTALLOWED
        """
        specifies a mouse pointer which symbolizes \"chaining not allowed\".
        """

__all__ = ['SystemPointer', 'SystemPointerEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.embed
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_storage import XStorage as XStorage_8e460a32
if typing.TYPE_CHECKING:
    from ..beans.named_value import NamedValue as NamedValue_a37a0af3
    from ..io.x_stream import XStream as XStream_678908a4

class XStorage2(XStorage_8e460a32):
    """
    This interface extends the base XStorage interface.

    See Also:
        `API XStorage2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1embed_1_1XStorage2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.embed'
    __ooo_full_ns__: str = 'com.sun.star.embed.XStorage2'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.embed.XStorage2'

    @abstractmethod
    def cloneEncryptedStream(self, sStreamName: str, aEncryptionData: typing.Tuple[NamedValue_a37a0af3, ...]) -> XStream_678908a4:
        """
        allows to get readonly copy of a child encrypted stream with encryption data.
        
        If storage does not allow any encryption this method will always throw com.sun.star.packages.NoEncryptionException.
        
        The stream is open in readonly mode so the com.sun.star.io.XStream.getOutputStream() method will return an empty reference.
        
        This method allows to specify encryption data for the child stream explicitly.

        Raises:
            com.sun.star.embed.InvalidStorageException: ``InvalidStorageException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.packages.NoEncryptionException: ``NoEncryptionException``
            com.sun.star.packages.WrongPasswordException: ``WrongPasswordException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.embed.StorageWrappedTargetException: ``StorageWrappedTargetException``
        """
        ...
    @abstractmethod
    def openEncryptedStream(self, sStreamName: str, nOpenMode: int, aEncryptionData: typing.Tuple[NamedValue_a37a0af3, ...]) -> XStream_678908a4:
        """
        allows to get access to a child encrypted stream with EncryptionData.
        
        If storage does not allow any encryption this method will always throw com.sun.star.packages.NoEncryptionException.
        
        In case the stream is open in readonly mode the com.sun.star.io.XStream.getOutputStream() method will return an empty reference.

        Raises:
            com.sun.star.embed.InvalidStorageException: ``InvalidStorageException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.packages.NoEncryptionException: ``NoEncryptionException``
            com.sun.star.packages.WrongPasswordException: ``WrongPasswordException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.embed.StorageWrappedTargetException: ``StorageWrappedTargetException``
        """
        ...

__all__ = ['XStorage2']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.document
from __future__ import annotations
import typing
from abc import abstractproperty
from .x_document_event_broadcaster import XDocumentEventBroadcaster as XDocumentEventBroadcaster_b2f1126a
from .x_document_properties_supplier import XDocumentPropertiesSupplier as XDocumentPropertiesSupplier_dc4b137f
from .x_embedded_scripts import XEmbeddedScripts as XEmbeddedScripts_1ab50eb1
from .x_event_broadcaster import XEventBroadcaster as XEventBroadcaster_2b120f2b
from .x_events_supplier import XEventsSupplier as XEventsSupplier_ecd0e88
from .x_undo_manager_supplier import XUndoManagerSupplier as XUndoManagerSupplier_5aae1064
from .x_view_data_supplier import XViewDataSupplier as XViewDataSupplier_2ae20f28
from ..frame.x_model import XModel as XModel_7a6e095c
from ..frame.x_storable import XStorable as XStorable_998f0aa7
from ..util.x_modifiable import XModifiable as XModifiable_a4f60b0a
from ..view.x_print_job_broadcaster import XPrintJobBroadcaster as XPrintJobBroadcaster_19ea0ead
from ..view.x_printable import XPrintable as XPrintable_9a5b0abc
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73

class OfficeDocument(XDocumentEventBroadcaster_b2f1126a, XDocumentPropertiesSupplier_dc4b137f, XEmbeddedScripts_1ab50eb1, XEventBroadcaster_2b120f2b, XEventsSupplier_ecd0e88, XUndoManagerSupplier_5aae1064, XViewDataSupplier_2ae20f28, XModel_7a6e095c, XStorable_998f0aa7, XModifiable_a4f60b0a, XPrintJobBroadcaster_19ea0ead, XPrintable_9a5b0abc):
    """
    Service Class

    abstract service which specifies a storable and printable document
    
    All major document-like components should support this service instead of simple components which supports a com.sun.star.frame.Controller or pure com.sun.star.awt.XWindow only.
    
    **since**
    
        LibreOffice 4.2

    See Also:
        `API OfficeDocument <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1document_1_1OfficeDocument.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.document'
    __ooo_full_ns__: str = 'com.sun.star.document.OfficeDocument'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def InteropGrabBag(self) -> typing.Tuple[PropertyValue_c9610c73, ...]:
        """
        Grab bag of document properties, used as a string-any map for interim interop purposes.
        
        This property is intentionally not handled by the ODF filter. Any member that should be handled there should be first moved out from this grab bag to a separate property.
        
        **since**
        
            LibreOffice 4.2
        """
        ...

    @abstractproperty
    def ApplyFormDesignMode(self) -> bool:
        """
        controls the initial (on-load) behavior of the form controls in the document
        
        If set to TRUE, upon loading the document, the form controls will be in design mode.If set to FALSE, they will be alive, i.e. operational.With this, you may control if your document works primarily as a form document.
        """
        ...

    @abstractproperty
    def AutomaticControlFocus(self) -> bool:
        """
        controls the focus behavior of the form controls in the document
        
        If this flag is set to TRUE, any view belonging to the document should focus the first control in the document. With this, you may control if your document works primarily as a form document.
        """
        ...

    @abstractproperty
    def RuntimeUID(self) -> str:
        """
        contains a unique id for the document
        
        Once calculated, the id must not change until the document has been closed. Upon closing it will not be made persistent. Thus, the document may get a different id every time it gets loaded.
        """
        ...


__all__ = ['OfficeDocument']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class EnhancedCustomShapeParameterType(metaclass=UnoConstMeta, type_name="com.sun.star.drawing.EnhancedCustomShapeParameterType", name_space="com.sun.star.drawing"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.drawing.EnhancedCustomShapeParameterType``"""
        pass

    class EnhancedCustomShapeParameterTypeEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.drawing.EnhancedCustomShapeParameterType", name_space="com.sun.star.drawing"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.drawing.EnhancedCustomShapeParameterType`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.drawing import EnhancedCustomShapeParameterType as EnhancedCustomShapeParameterType
    else:
        # keep document generators happy
        from ...lo.drawing.enhanced_custom_shape_parameter_type import EnhancedCustomShapeParameterType as EnhancedCustomShapeParameterType

    class EnhancedCustomShapeParameterTypeEnum(IntEnum):
        """
        Enum of Const Class EnhancedCustomShapeParameterType

        defines how an EnhancedCustomShapeParameter has to be interpreted
        """
        NORMAL = EnhancedCustomShapeParameterType.NORMAL
        """
        the value of the point component is normal, the Coordinate is taken as it is
        """
        EQUATION = EnhancedCustomShapeParameterType.EQUATION
        """
        the value of the point component has to be interpreted as index to an Equation
        """
        ADJUSTMENT = EnhancedCustomShapeParameterType.ADJUSTMENT
        """
        the value of the point component has to be interpreted as index into the list of AdjustmentValues
        """
        LEFT = EnhancedCustomShapeParameterType.LEFT
        """
        the logical left border of the CustomShape is used
        """
        TOP = EnhancedCustomShapeParameterType.TOP
        """
        the logical top border of the CustomShape is used
        """
        RIGHT = EnhancedCustomShapeParameterType.RIGHT
        """
        the logical right border of the CustomShape is used
        """
        BOTTOM = EnhancedCustomShapeParameterType.BOTTOM
        """
        the logical bottom border of the CustomShape is used
        """
        XSTRETCH = EnhancedCustomShapeParameterType.XSTRETCH
        """
        the x value of the stretch point is used
        """
        YSTRETCH = EnhancedCustomShapeParameterType.YSTRETCH
        """
        the y value of the stretch point is used
        """
        HASSTROKE = EnhancedCustomShapeParameterType.HASSTROKE
        """
        If the shape has a line style, a value of 1 is used.
        """
        HASFILL = EnhancedCustomShapeParameterType.HASFILL
        """
        If the shape has a fill style, a value of 1 is used.
        """
        WIDTH = EnhancedCustomShapeParameterType.WIDTH
        """
        The width of the svg:viewBox is used.
        """
        HEIGHT = EnhancedCustomShapeParameterType.HEIGHT
        """
        The height of the svg:viewBox is used.
        """
        LOGWIDTH = EnhancedCustomShapeParameterType.LOGWIDTH
        """
        The logical width of the shape is used.
        """
        LOGHEIGHT = EnhancedCustomShapeParameterType.LOGHEIGHT
        """
        The logical height of the shape is used.
        """

__all__ = ['EnhancedCustomShapeParameterType', 'EnhancedCustomShapeParameterTypeEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.text
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class RubyAdjust(metaclass=UnoEnumMeta, type_name="com.sun.star.text.RubyAdjust", name_space="com.sun.star.text"):
        """Dynamically created class that represents ``com.sun.star.text.RubyAdjust`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.text.RubyAdjust import BLOCK as RUBY_ADJUST_BLOCK
        from com.sun.star.text.RubyAdjust import CENTER as RUBY_ADJUST_CENTER
        from com.sun.star.text.RubyAdjust import INDENT_BLOCK as RUBY_ADJUST_INDENT_BLOCK
        from com.sun.star.text.RubyAdjust import LEFT as RUBY_ADJUST_LEFT
        from com.sun.star.text.RubyAdjust import RIGHT as RUBY_ADJUST_RIGHT

        class RubyAdjust(uno.Enum):
            """
            Enum Class


            See Also:
                `API RubyAdjust <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1text.html#adf417fe4b45f486fe88af93ad0b59efb>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.text.RubyAdjust', value)

            __ooo_ns__: str = 'com.sun.star.text'
            __ooo_full_ns__: str = 'com.sun.star.text.RubyAdjust'
            __ooo_type_name__: str = 'enum'

            BLOCK = RUBY_ADJUST_BLOCK
            """
            adjusted to both borders / stretched
            """
            CENTER = RUBY_ADJUST_CENTER
            """
            the object is adjusted to the center.

            centric adjusted.
            """
            INDENT_BLOCK = RUBY_ADJUST_INDENT_BLOCK
            """
            adjusted to both borders except for a small indent on both sides
            """
            LEFT = RUBY_ADJUST_LEFT
            """
            the object is left adjusted.

            text flows to the left side of the object.

            adjusted to the left.
            """
            RIGHT = RUBY_ADJUST_RIGHT
            """
            the object is right adjusted.

            text flows to the right side of the object.

            adjusted to the right.
            """
    else:
        # keep document generators happy
        from ...lo.text.ruby_adjust import RubyAdjust as RubyAdjust


__all__ = ['RubyAdjust']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
import typing
from abc import abstractmethod
from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6
if typing.TYPE_CHECKING:
    from .x_auto_text_group import XAutoTextGroup as XAutoTextGroup_c9770c70

class XAutoTextContainer(XNameAccess_e2ab0cf6):
    """
    handles blocks of AutoTextEntry.

    See Also:
        `API XAutoTextContainer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1text_1_1XAutoTextContainer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.XAutoTextContainer'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.text.XAutoTextContainer'

    @abstractmethod
    def insertNewByName(self, aGroupName: str) -> XAutoTextGroup_c9770c70:
        """
        creates a new AutoText group.
        
        The name must follow the pattern groupname*pathid, where:
        
        If only groupname is specified, the path defaults to 0, the Office Basis layer.Note that in some systems the user may lack of write access to the Office Basis directory.
        
        Example:

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.ElementExistException: ``ElementExistException``
        """
        ...
    @abstractmethod
    def removeByName(self, aGroupName: str) -> None:
        """
        deletes the specified AutoText group.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...

__all__ = ['XAutoTextContainer']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ui
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
from ..container.container_event import ContainerEvent as ContainerEvent_ea50e70
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing


class ConfigurationEvent(ContainerEvent_ea50e70):
    """
    Struct Class

    this event is broadcasted by a configuration manager whenever the state of user interface element has changed.
    
    **since**
    
        OOo 2.0

    See Also:
        `API ConfigurationEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ui_1_1ConfigurationEvent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui'
    __ooo_full_ns__: str = 'com.sun.star.ui.ConfigurationEvent'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.ui.ConfigurationEvent'
    """Literal Constant ``com.sun.star.ui.ConfigurationEvent``"""

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = None, Accessor: typing.Optional[object] = None, Element: typing.Optional[object] = None, ReplacedElement: typing.Optional[object] = None, ResourceURL: typing.Optional[str] = '', aInfo: typing.Optional[object] = None) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            Accessor (object, optional): Accessor value.
            Element (object, optional): Element value.
            ReplacedElement (object, optional): ReplacedElement value.
            ResourceURL (str, optional): ResourceURL value.
            aInfo (object, optional): aInfo value.
        """

        if isinstance(Source, ConfigurationEvent):
            oth: ConfigurationEvent = Source
            self.Source = oth.Source
            self.Accessor = oth.Accessor
            self.Element = oth.Element
            self.ReplacedElement = oth.ReplacedElement
            self.ResourceURL = oth.ResourceURL
            self.aInfo = oth.aInfo
            return

        kargs = {
            "Source": Source,
            "Accessor": Accessor,
            "Element": Element,
            "ReplacedElement": ReplacedElement,
            "ResourceURL": ResourceURL,
            "aInfo": aInfo,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._resource_url = kwargs["ResourceURL"]
        self._a_info = kwargs["aInfo"]
        inst_keys = ('ResourceURL', 'aInfo')
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def ResourceURL(self) -> str:
        """
        contains the resource URL of the user interface element or a configuration manager, which has been changed, inserted or replaced.
        """
        return self._resource_url

    @ResourceURL.setter
    def ResourceURL(self, value: str) -> None:
        self._resource_url = value

    @property
    def aInfo(self) -> object:
        """
        contains additional information about this configuration event.
        
        The type depends on the specific implementation.
        """
        return self._a_info

    @aInfo.setter
    def aInfo(self, value: object) -> None:
        self._a_info = value


__all__ = ['ConfigurationEvent']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.document
from __future__ import annotations
from ..container.x_container_query import XContainerQuery as XContainerQuery_1cdd0edc
from ..container.x_name_container import XNameContainer as XNameContainer_cb90e47
from .x_type_detection import XTypeDetection as XTypeDetection_ff7e0e00
from ..util.x_flushable import XFlushable as XFlushable_9a420ab4

class TypeDetection(XContainerQuery_1cdd0edc, XNameContainer_cb90e47, XTypeDetection_ff7e0e00, XFlushable_9a420ab4):
    """
    Service Class

    encapsulate a type detection service and provide read/write access on it's configuration data.
    
    It's possible to make a \"flat\" detection which may use internal configuration data only - or a \"deep\" detection which use special ExtendedTypeDetection services to look into the document stream. Last mode can be suppressed to perform the operation. Of course the results can't be guaranteed then. (e.g. in case the extension was changed)

    See Also:
        `API TypeDetection <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1document_1_1TypeDetection.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.document'
    __ooo_full_ns__: str = 'com.sun.star.document.TypeDetection'
    __ooo_type_name__: str = 'service'


__all__ = ['TypeDetection']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ucb
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class OpenMode(metaclass=UnoConstMeta, type_name="com.sun.star.ucb.OpenMode", name_space="com.sun.star.ucb"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.ucb.OpenMode``"""
        pass

    class OpenModeEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.ucb.OpenMode", name_space="com.sun.star.ucb"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.ucb.OpenMode`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.ucb import OpenMode as OpenMode
    else:
        # keep document generators happy
        from ...lo.ucb.open_mode import OpenMode as OpenMode

    class OpenModeEnum(IntEnum):
        """
        Enum of Const Class OpenMode

        These are the possible values for OpenCommandArgument.Mode.
        """
        ALL = OpenMode.ALL
        """
        open a folder, include all children in result set (documents and folders).
        """
        FOLDERS = OpenMode.FOLDERS
        """
        open a folder, include only children, that are folders, in result set.
        """
        DOCUMENTS = OpenMode.DOCUMENTS
        """
        open a folder, include only children, that are documents, in result set.
        """
        DOCUMENT = OpenMode.DOCUMENT
        """
        open a document.
        
        There are no special requirements for data access sharing.
        
        Note: There must be a data sink supplied in the OpenCommandArgument struct, if this value is set. This sink will be used by the content implementation to supply the document data.
        """
        DOCUMENT_SHARE_DENY_NONE = OpenMode.DOCUMENT_SHARE_DENY_NONE
        """
        open a document.
        
        Allow shared read and write access.
        
        Note: There must be a data sink supplied in the OpenCommandArgument struct, if this value is set. This sink will be used by the content implementation to supply the document data.
        """
        DOCUMENT_SHARE_DENY_WRITE = OpenMode.DOCUMENT_SHARE_DENY_WRITE
        """
        open a document.
        
        Deny shared write access.
        
        Note: There must be a data sink supplied in the OpenCommandArgument struct, if this value is set. This sink will be used by the content implementation to supply the document data.
        """

__all__ = ['OpenMode', 'OpenModeEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .table_page_break_data import TablePageBreakData as TablePageBreakData_8ac0de5

class XSheetPageBreak(XInterface_8f010a43):
    """
    provides access to page breaks in a sheet.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XSheetPageBreak <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetPageBreak.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.XSheetPageBreak'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sheet.XSheetPageBreak'

    @abstractmethod
    def getColumnPageBreaks(self) -> typing.Tuple[TablePageBreakData_8ac0de5, ...]:
        """
        returns a sequence of descriptions of all horizontal page breaks on the sheet.
        
        This includes manual and automatic page breaks. To add or remove manual breaks, use the com.sun.star.table.TableColumn.IsStartOfNewPage property of the column.
        """
        ...
    @abstractmethod
    def getRowPageBreaks(self) -> typing.Tuple[TablePageBreakData_8ac0de5, ...]:
        """
        returns a sequence of descriptions of all vertical page breaks on the sheet.
        
        This includes manual and automatic page breaks. To add or remove manual breaks, use the com.sun.star.table.TableRow.IsStartOfNewPage property of the row.
        """
        ...
    @abstractmethod
    def removeAllManualPageBreaks(self) -> None:
        """
        removes all manual page breaks on the sheet.
        """
        ...

__all__ = ['XSheetPageBreak']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.accessibility
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_accessible_text import XAccessibleText as XAccessibleText_5b77105b
if typing.TYPE_CHECKING:
    from .text_segment import TextSegment as TextSegment_1e5b0ee8

class XAccessibleTextMarkup(XAccessibleText_5b77105b):
    """
    Implement this interface to expose the text markups of a text.
    
    The XAccessibleTextMarkup interface is the main interface to expose text markups in a text, typically of a text document, that are used to reference other (parts of) documents. For supporting the XAccessibleTextMarkup.getTextMarkupIndex() method of this interface and other character related methods of the XAccessibleTextMarkup interface, it is necessary to also support the XAccessibleText interface.
    
    **since**
    
        OOo 3.0

    See Also:
        `API XAccessibleTextMarkup <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1accessibility_1_1XAccessibleTextMarkup.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.accessibility'
    __ooo_full_ns__: str = 'com.sun.star.accessibility.XAccessibleTextMarkup'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.accessibility.XAccessibleTextMarkup'

    @abstractmethod
    def getTextMarkup(self, TextMarkupIndex: int, TextMarkupType: int) -> TextSegment_1e5b0ee8:
        """
        Returns the text segment of the text markup of the given index and of the given text mark type.
        
        Throws IndexOutOfBoundsException, if given index is out of valid range.
        
        Throws IllegalArgumentException, if given text markup type is out of valid range.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def getTextMarkupAtIndex(self, CharIndex: int, TextMarkupType: int) -> typing.Tuple[TextSegment_1e5b0ee8, ...]:
        """
        returns a sequence of the text segments of the text markups at the given character index and of the given text markup type.
        
        Throws IndexOutOfBoundsException, if given character index is out of range [0..number of characters in the text).
        
        Throws IllegalArgumentException, if given text markup type is out of valid range.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def getTextMarkupCount(self, TextMarkupType: int) -> int:
        """
        Returns the number of text markup of the given text markup type of a text.
        
        Throws IllegalArgumentException, if given text markup type is out of valid range.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XAccessibleTextMarkup']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.java
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .java_initialization_exception import JavaInitializationException as JavaInitializationException_8b6211a3
from ..uno.x_interface import XInterface as XInterface_8f010a43

class JavaVMCreationFailureException(JavaInitializationException_8b6211a3):
    """
    Exception Class

    indicates that the Java Virtual Machine could not be created
    
    This exception can be thrown when the creation of the Java Virtual Machine failed, even if the runtime library could be loaded. Possible reasons for a failure are that JNI_CreateJavaVM returns an error code that reflects a failure, JNI_CreateJavaVM does not return because it tries to quit the process ( _exit), the shared library is corrupted, so that the symbols for JNI_GetDefaultVMInitArgs or JNI_CreateJavaVM cannot be found, etc.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API JavaVMCreationFailureException <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1java_1_1JavaVMCreationFailureException.html>`_
    """

    __ooo_ns__: str = 'com.sun.star.java'
    __ooo_full_ns__: str = 'com.sun.star.java.JavaVMCreationFailureException'
    __ooo_type_name__: str = 'exception'
    __pyunointerface__: str = 'com.sun.star.java.JavaVMCreationFailureException'
    __pyunostruct__: str = 'com.sun.star.java.JavaVMCreationFailureException'

    typeName: str = 'com.sun.star.java.JavaVMCreationFailureException'
    """Literal Constant ``com.sun.star.java.JavaVMCreationFailureException``"""

    def __init__(self, Message: typing.Optional[str] = '', Context: typing.Optional[XInterface_8f010a43] = None, ErrorCode: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
            ErrorCode (int, optional): ErrorCode value.
        """
        kargs = {
            "Message": Message,
            "Context": Context,
            "ErrorCode": ErrorCode,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._error_code = kwargs["ErrorCode"]
        inst_keys = ('ErrorCode',)
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)

    @property
    def ErrorCode(self) -> int:
        """
        contains an error code that reflects the returned error code of JNI_CreateJavaVM or other errors.
        
        A negative value represents the returned error code of JNI_CreateJavaVM. All other values indicate a different cause.
        """
        return self._error_code
    
    @ErrorCode.setter
    def ErrorCode(self, value: int) -> None:
        self._error_code = value


__all__ = ['JavaVMCreationFailureException']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.logging
from __future__ import annotations
from abc import abstractproperty
from .x_log_handler import XLogHandler as XLogHandler_c7f80c27

class XConsoleHandler(XLogHandler_c7f80c27):
    """
    implemented by a log handler whose output channel is the processes console.
    
    Note that a console handler will ignore its formatter's head and tail, since it cannot decided whether they should be emitted on stdout or stderr.
    
    **since**
    
        OOo 2.3

    See Also:
        `API XConsoleHandler <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1logging_1_1XConsoleHandler.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.logging'
    __ooo_full_ns__: str = 'com.sun.star.logging.XConsoleHandler'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.logging.XConsoleHandler'

    @abstractproperty
    def Threshold(self) -> int:
        """
        denotes the LogLevel threshold used to determine to which console the events should be logged.
        
        Events with a level greater or equal to Threshold will be logged to stderr, all others to stdout.
        
        The default value for this attribute is LogLevel.SEVERE.
        """
        ...


__all__ = ['XConsoleHandler']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing.framework
from __future__ import annotations
from abc import abstractmethod
from .x_configuration import XConfiguration as XConfiguration_8f0511a0

class Configuration(XConfiguration_8f0511a0):
    """
    Service Class

    This service provides the means for constructing new configurations.
    
    Most likely use is the XConfigurationController.restoreConfiguration() method.

    See Also:
        `API Configuration <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1Configuration.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing.framework'
    __ooo_full_ns__: str = 'com.sun.star.drawing.framework.Configuration'
    __ooo_type_name__: str = 'service'

    @abstractmethod
    def create(self) -> None:
        """
        Create an empty configuration.
        
        This should not be necessary very often. Changes to an existing configuration are more likely.
        """
        ...

__all__ = ['Configuration']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.task
from __future__ import annotations
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XJobExecutor(XInterface_8f010a43):
    """
    starts action for any triggered event from outside
    
    If somewhere from outside trigger an event on this interface it will be used to find any registered service inside configuration of this executor. If somewhere could be found it will be started and controlled by this instance. After it finish his work it's possible to deactivate further startups or let him run again if a new event will be detected later.

    See Also:
        `API XJobExecutor <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1task_1_1XJobExecutor.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.task'
    __ooo_full_ns__: str = 'com.sun.star.task.XJobExecutor'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.task.XJobExecutor'

    @abstractmethod
    def trigger(self, Event: str) -> None:
        """
        trigger event to start registered jobs
        
        Jobs are registered in configuration and will be started by executor automatically, if they are registered for triggered event. The meaning of given string Event mustn't be known. Because for the executor it's enough to use it for searching a registered job inside his own configuration. So no special events will be defined here.
        """
        ...

__all__ = ['XJobExecutor']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
from abc import abstractmethod, abstractproperty
from ..container.x_enumeration_access import XEnumerationAccess as XEnumerationAccess_4bac0ffc
from ..container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d
from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6
if typing.TYPE_CHECKING:
    from .x_external_sheet_cache import XExternalSheetCache as XExternalSheetCache_1a420e89

class XExternalDocLink(XEnumerationAccess_4bac0ffc, XIndexAccess_f0910d6d, XNameAccess_e2ab0cf6):
    """
    Primary interface for the com.sun.star.sheet.ExternalDocLink service.
    
    **since**
    
        OOo 3.1

    See Also:
        `API XExternalDocLink <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XExternalDocLink.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.XExternalDocLink'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sheet.XExternalDocLink'

    @abstractmethod
    def addSheetCache(self, aSheetName: str, DynamicCache: bool) -> XExternalSheetCache_1a420e89:
        """
        This method adds a new sheet cache instance to the external document link for a specified sheet name. If a sheet cache instance already exists for the specified name, then the existing instance is returned.
        
        Note that a sheet name lookup is performed in a case-insensitive fashion.
        """
        ...
    @abstractproperty
    def TokenIndex(self) -> int:
        """
        Index corresponding to the external document link.
        
        This index value corresponds with the external document represented by an instance of com.sun.star.sheet.ExternalDocLink. This value is stored within a formula token instance.
        
        Each external document cache instance has a unique index value, and this index value can be used to retrieve the corresponding external document cache from the parent com.sun.star.sheet.ExternalDocLinks instance.
        """
        ...


__all__ = ['XExternalDocLink']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.beans
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from com.sun.star.beans.PropertyState import PropertyStateProto

class XPropertyWithState(XInterface_8f010a43):
    """
    makes it possible to query information about the state of this object, seen as a property contained in a property set.
    
    This interface provides direct access to operations that are available if the containing property set implements XPropertyState.
    
    The state contains the information if:
    
    Generally objects that implement this interface also implement XProperty.

    See Also:
        `API XPropertyWithState <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1beans_1_1XPropertyWithState.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.beans'
    __ooo_full_ns__: str = 'com.sun.star.beans.XPropertyWithState'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.beans.XPropertyWithState'

    @abstractmethod
    def getDefaultAsProperty(self) -> XInterface_8f010a43:
        """
        If no default exists, is not known or is void, then the return value is NULL.

        Raises:
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...
    @abstractmethod
    def getStateAsProperty(self) -> PropertyStateProto:
        """
        """
        ...
    @abstractmethod
    def setToDefaultAsProperty(self) -> None:
        """
        sets this to its default value.
        
        The value depends on the implementation of this interface. If this is a bound property, the value changes before the change events are fired. If this is a constrained property, the vetoable event is fired before the property value changes.

        Raises:
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...

__all__ = ['XPropertyWithState']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
import uno
from enum import Enum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class FontWidth(metaclass=UnoConstMeta, type_name="com.sun.star.awt.FontWidth", name_space="com.sun.star.awt"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.awt.FontWidth``"""
        pass

    class FontWidthEnum(Enum, metaclass=ConstEnumMeta, type_name="com.sun.star.awt.FontWidth", name_space="com.sun.star.awt"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.awt.FontWidth`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.awt import FontWidth as FontWidth
    else:
        # keep document generators happy
        from ...lo.awt.font_width import FontWidth as FontWidth

    class FontWidthEnum(Enum):
        """
        Enum of Const Class FontWidth

        These values are used to specify the width of the characters of a font.
        
        They may be expanded in future versions.
        """
        DONTKNOW = FontWidth.DONTKNOW
        """
        The width of the font is not specified/known.
        """
        ULTRACONDENSED = FontWidth.ULTRACONDENSED
        """
        The width of the font is condensed to 50%.
        """
        EXTRACONDENSED = FontWidth.EXTRACONDENSED
        """
        The width of the font is condensed to 60%.
        """
        CONDENSED = FontWidth.CONDENSED
        """
        The width of the font is condensed to 75%.
        """
        SEMICONDENSED = FontWidth.SEMICONDENSED
        """
        The width of the font is condensed to 90%.
        """
        NORMAL = FontWidth.NORMAL
        """
        The width of the font is normal.
        """
        SEMIEXPANDED = FontWidth.SEMIEXPANDED
        """
        The width of the font is expanded to 110%.
        """
        EXPANDED = FontWidth.EXPANDED
        """
        The width of the font is expanded to 150%.
        """
        EXTRAEXPANDED = FontWidth.EXTRAEXPANDED
        """
        The width of the font is expanded to 175%.
        """
        ULTRAEXPANDED = FontWidth.ULTRAEXPANDED
        """
        The width of the font is expanded to 200%.
        """

__all__ = ['FontWidth', 'FontWidthEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text


class BibliographyDataType(object):
    """
    Const Class

    These values define the type of bibliographic data like book, journal, magazine, etc.

    See Also:
        `API BibliographyDataType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataType.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.BibliographyDataType'
    __ooo_type_name__: str = 'const'

    ARTICLE = 0
    """
    An article from a journal or magazine.
    """
    BOOK = 1
    """
    A book with an explicit publisher.
    """
    BOOKLET = 2
    """
    A work that is printed and bound, but without a named publisher or sponsoring institution.
    """
    CONFERENCE = 3
    """
    An article in the proceedings of a conference.
    
    This entry is identical to the \"inproceedings\" entry and is included for compatibility with BiBTex.
    """
    INBOOK = 4
    """
    A part of a book, which may be a chapter and/or a range of pages.
    """
    INCOLLECTION = 5
    """
    A part of a book with its own title.
    """
    INPROCEEDINGS = 6
    """
    An article in the proceedings of a conference.
    """
    JOURNAL = 7
    """
    A journal or magazine.
    """
    MANUAL = 8
    """
    Technical documentation.
    """
    MASTERSTHESIS = 9
    """
    A Master's thesis.
    """
    MISC = 10
    """
    This type is used when nothing else seems appropriate.
    """
    PHDTHESIS = 11
    """
    A PhD thesis.
    """
    PROCEEDINGS = 12
    """
    The proceedings of a conference.
    """
    TECHREPORT = 13
    """
    A report published by a school or other institution, usually numbered within a series.
    """
    UNPUBLISHED = 14
    """
    A document with an author and title, but not formally published.
    """
    EMAIL = 15
    """
    An eMail document.
    """
    WWW = 16
    """
    A Web document.
    """
    CUSTOM1 = 17
    """
    A user defined document type.
    """
    CUSTOM2 = 18
    """
    A user defined document type.
    """
    CUSTOM3 = 19
    """
    A user defined document type.
    """
    CUSTOM4 = 20
    """
    A user defined document type.
    """
    CUSTOM5 = 21
    """
    A user defined document type.
    """

__all__ = ['BibliographyDataType']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.view
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_selection_supplier import XSelectionSupplier as XSelectionSupplier_fed20e15
if typing.TYPE_CHECKING:
    from ..container.x_enumeration import XEnumeration as XEnumeration_f2180daa

class XMultiSelectionSupplier(XSelectionSupplier_fed20e15):
    """
    makes it possible to append and remove objects from a selection.
    
    The method XSelectionSupplier.setSelection() for an instance that also supports XMultiSelectionSupplier should be implemented that it also takes either a selectable object or a sequence of selectable objects.
    
    Adding an object more than once to a selection should not toggle the selection for that object but only select it once

    See Also:
        `API XMultiSelectionSupplier <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1view_1_1XMultiSelectionSupplier.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.view'
    __ooo_full_ns__: str = 'com.sun.star.view.XMultiSelectionSupplier'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.view.XMultiSelectionSupplier'

    @abstractmethod
    def addSelection(self, Selection: object) -> bool:
        """
        adds the object or the objects represented by Selection to the selection of this XMultiSelectionSupplier.
        
        Adding an object to the selection that is already part of the selection should not raise this exception

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def clearSelection(self) -> None:
        """
        clears the selection of this XMultiSelectionSupplier.
        """
        ...
    @abstractmethod
    def createReverseSelectionEnumeration(self) -> XEnumeration_f2180daa:
        """
        """
        ...
    @abstractmethod
    def createSelectionEnumeration(self) -> XEnumeration_f2180daa:
        """
        """
        ...
    @abstractmethod
    def getSelectionCount(self) -> int:
        """
        returns the number of selected objects of this XMultiSelectionSupplier.
        """
        ...
    @abstractmethod
    def removeSelection(self, Selection: object) -> None:
        """
        remove the object or objects represented by Selection from the selection of this XMultiSelectionSupplier.
        
        Removing an object from the selection that is not part of the selection should not raise this exception

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XMultiSelectionSupplier']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.geometry
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .real_point2_d import RealPoint2D as RealPoint2D_d6e70c78

class XMapping2D(XInterface_8f010a43):
    """
    Interface defining an arbitrary bijective mapping from R^2 to R^2.
    
    This interface provides methods to define an arbitrary bijective mapping from R^2 to R^2, i.e. from the two-dimensional space of real numbers onto itself, as is representable by the double floating point type. The mapping must be bijective, i.e. map a pair of real numbers to exactly one other pair of real numbers and vice versa, to facilitate a working inverse. Bijectiveness also implies completeness, i.e. for every pair of real numbers there must be another pair that is mapped upon them.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XMapping2D <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1geometry_1_1XMapping2D.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.geometry'
    __ooo_full_ns__: str = 'com.sun.star.geometry.XMapping2D'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.geometry.XMapping2D'

    @abstractmethod
    def map(self, aPoint: RealPoint2D_d6e70c78) -> RealPoint2D_d6e70c78:
        """
        Forward 2D mapping function.
        """
        ...
    @abstractmethod
    def mapInverse(self, aPoint: RealPoint2D_d6e70c78) -> RealPoint2D_d6e70c78:
        """
        Inverse 2D mapping function.
        
        The following invariant must hold: map(mapInverse(p))=p. This effectively rules out non-bijective mappings.
        """
        ...

__all__ = ['XMapping2D']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class TransliterationType(metaclass=UnoConstMeta, type_name="com.sun.star.i18n.TransliterationType", name_space="com.sun.star.i18n"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.i18n.TransliterationType``"""
        pass

    class TransliterationTypeEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.i18n.TransliterationType", name_space="com.sun.star.i18n"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.i18n.TransliterationType`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.i18n import TransliterationType as TransliterationType
    else:
        # keep document generators happy
        from ...lo.i18n.transliteration_type import TransliterationType as TransliterationType

    class TransliterationTypeEnum(IntEnum):
        """
        Enum of Const Class TransliterationType

        Bitmask transliteration types used with XTransliteration.getType() and XTransliteration.getAvailableModules() methods.
        
        Non-IGNORE type modules provide XTransliteration.transliterate(). IGNORE type modules provide XTransliteration.equals() and XTransliteration.transliterateRange().
        """
        NONE = TransliterationType.NONE
        ONE_TO_ONE = TransliterationType.ONE_TO_ONE
        """
        A transliteration module is ONE_TO_ONE if and only if it's mapping between characters is one to one like a-z to A-Z.
        
        Transliteration modules of this type can be used as choice in regular expressions based search/replace.
        """
        NUMERIC = TransliterationType.NUMERIC
        """
        A transliteration module can have attribute NUMERIC if it transliterates numbers in different languages like Chinese numbers to Arabic numbers and vice versa.
        
        This mapping need not be one to one, it should be primarily used by number formatting and parsing methods.
        """
        ONE_TO_ONE_NUMERIC = TransliterationType.ONE_TO_ONE_NUMERIC
        """
        A transliteration module is ONE_TO_ONE_NUMERIC if it offers both one to one mapping and handles number also.
        """
        IGNORE = TransliterationType.IGNORE
        """
        With a transliteration IGNORE case, the regular expression A-Z can be transformed to a-z, for example.
        """
        CASCADE = TransliterationType.CASCADE
        """
        If the transliteration is cascaded (uses more than one algorithm).
        """

__all__ = ['TransliterationType', 'TransliterationTypeEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
from abc import abstractproperty
from ..drawing.shape import Shape as Shape_85cc09e5
if typing.TYPE_CHECKING:
    from ..uno.x_interface import XInterface as XInterface_8f010a43

class Shape(Shape_85cc09e5):
    """
    Service Class

    specifies the service of shapes in a spreadsheet document
    
    **since**
    
        LibreOffice 6.3

    See Also:
        `API Shape <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1Shape.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.Shape'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Anchor(self) -> XInterface_8f010a43:
        """
        contains the object where this shape is anchored on.
        
        Possible objects are XSpreadsheet and XCell.
        """
        ...

    @abstractproperty
    def HoriOrientPosition(self) -> int:
        """
        contains the horizontal position of the object (1/100 mm).
        
        The position is relative to the anchor object.
        
        If the underlying table layout direction is left to right the position is the difference of the left top edge of the anchor object and the left top edge of the drawing object.
        
        If the underlying table layout direction is right to left the position is the difference of the right top edge of the anchor object and the right top edge of the drawing object.
        """
        ...

    @abstractproperty
    def ResizeWithCell(self) -> bool:
        """
        If set, the shape will resize with the cell.
        
        Only works when shape is anchored to a cell.
        
        **since**
        
            LibreOffice 6.3
        """
        ...

    @abstractproperty
    def VertOrientPosition(self) -> int:
        """
        contains the vertical position of the object (1/100 mm).
        
        The position is relative to the anchor object.
        
        If the underlying table layout direction is left to right the position is the difference of the left top edge of the anchor object and the left top edge of the drawing object.
        
        If the underlying table layout direction is right to left the position is the difference of the right top edge of the anchor object and the right top edge of the drawing object.
        """
        ...


__all__ = ['Shape']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.script
import uno
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from com.sun.star.script import XAllListenerAdapterService as XAllListenerAdapterService
    setattr(XAllListenerAdapterService, '__ooo_ns__', 'com.sun.star.script')
    setattr(XAllListenerAdapterService, '__ooo_full_ns__', 'com.sun.star.script.XAllListenerAdapterService')
    setattr(XAllListenerAdapterService, '__ooo_type_name__', 'interface')
else:
    if TYPE_CHECKING:
        from com.sun.star.script import XAllListenerAdapterService as XAllListenerAdapterService
    else:
        # keep document generators happy
        from ...lo.script.x_all_listener_adapter_service import XAllListenerAdapterService as XAllListenerAdapterService

__all__ = ['XAllListenerAdapterService']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_native_number_supplier import XNativeNumberSupplier as XNativeNumberSupplier_1eb80ec4
if typing.TYPE_CHECKING:
    from ..lang.locale import Locale as Locale_70d308fa

class XNativeNumberSupplier2(XNativeNumberSupplier_1eb80ec4):
    """
    Methods to convert between strings of ASCII Arabic digits and native numeral strings, using NatNum params.
    
    **since**
    
        LibreOffice 6.1

    See Also:
        `API XNativeNumberSupplier2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1i18n_1_1XNativeNumberSupplier2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.XNativeNumberSupplier2'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.i18n.XNativeNumberSupplier2'

    @abstractmethod
    def getNativeNumberStringParams(self, NumberString: str, Locale: Locale_70d308fa, NativeNumberMode: int, NativeNumberParameters: str) -> str:
        """
        Returns native number string for given number string, using NatNum params.
        """
        ...

__all__ = ['XNativeNumberSupplier2']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class CommandInfo(object):
    """
    Struct Class

    describes a command.

    See Also:
        `API CommandInfo <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1CommandInfo.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.CommandInfo'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.ucb.CommandInfo'
    """Literal Constant ``com.sun.star.ucb.CommandInfo``"""

    def __init__(self, Name: typing.Optional[str] = '', Handle: typing.Optional[int] = 0, ArgType: typing.Optional[object] = None) -> None:
        """
        Constructor

        Arguments:
            Name (str, optional): Name value.
            Handle (int, optional): Handle value.
            ArgType (object, optional): ArgType value.
        """
        super().__init__()

        if isinstance(Name, CommandInfo):
            oth: CommandInfo = Name
            self.Name = oth.Name
            self.Handle = oth.Handle
            self.ArgType = oth.ArgType
            return

        kargs = {
            "Name": Name,
            "Handle": Handle,
            "ArgType": ArgType,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._name = kwargs["Name"]
        self._handle = kwargs["Handle"]
        self._arg_type = kwargs["ArgType"]


    @property
    def Name(self) -> str:
        """
        contains the name of a command.
        """
        return self._name

    @Name.setter
    def Name(self, value: str) -> None:
        self._name = value

    @property
    def Handle(self) -> int:
        """
        contains an implementation specific handle for the command.
        
        It may be -1 if the implementation has no handle.
        """
        return self._handle

    @Handle.setter
    def Handle(self, value: int) -> None:
        self._handle = value

    @property
    def ArgType(self) -> object:
        """
        contains the type of the command's argument.
        """
        return self._arg_type

    @ArgType.setter
    def ArgType(self, value: object) -> None:
        self._arg_type = value


__all__ = ['CommandInfo']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.report
from __future__ import annotations
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..container.x_child import XChild as XChild_a6390b07
from ..lang.x_component import XComponent as XComponent_98dc0ab5

class XFunction(XPropertySet_bc180bfa, XChild_a6390b07, XComponent_98dc0ab5):
    """
    specifies a format condition for a control.

    See Also:
        `API XFunction <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1report_1_1XFunction.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.report'
    __ooo_full_ns__: str = 'com.sun.star.report.XFunction'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.report.XFunction'

    @abstractproperty
    def DeepTraversing(self) -> bool:
        """
        specifies if sub reports should be traversed as well.
        """
        ...

    @abstractproperty
    def Formula(self) -> str:
        """
        defines the formula of this function
        """
        ...

    @abstractproperty
    def InitialFormula(self) -> object:
        """
        defines the formula for the initial value
        """
        ...

    @abstractproperty
    def Name(self) -> str:
        """
        defines the name of the function
        """
        ...

    @abstractproperty
    def PreEvaluated(self) -> bool:
        """
        specifies if the function should be evaluated before the report element will be executed.
        """
        ...


__all__ = ['XFunction']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.frame
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..beans.property_value import PropertyValue as PropertyValue_c9610c73


class DispatchStatement(object):
    """
    Struct Class

    represents a dispatch statement from a recorded macro
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API DispatchStatement <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1frame_1_1DispatchStatement.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.DispatchStatement'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.frame.DispatchStatement'
    """Literal Constant ``com.sun.star.frame.DispatchStatement``"""

    def __init__(self, aArgs: typing.Optional[typing.Tuple[PropertyValue_c9610c73, ...]] = (), aCommand: typing.Optional[str] = '', aTarget: typing.Optional[str] = '', nFlags: typing.Optional[int] = 0, bIsComment: typing.Optional[bool] = False) -> None:
        """
        Constructor

        Arguments:
            aArgs (typing.Tuple[PropertyValue, ...], optional): aArgs value.
            aCommand (str, optional): aCommand value.
            aTarget (str, optional): aTarget value.
            nFlags (int, optional): nFlags value.
            bIsComment (bool, optional): bIsComment value.
        """
        super().__init__()

        if isinstance(aArgs, DispatchStatement):
            oth: DispatchStatement = aArgs
            self.aArgs = oth.aArgs
            self.aCommand = oth.aCommand
            self.aTarget = oth.aTarget
            self.nFlags = oth.nFlags
            self.bIsComment = oth.bIsComment
            return

        kargs = {
            "aArgs": aArgs,
            "aCommand": aCommand,
            "aTarget": aTarget,
            "nFlags": nFlags,
            "bIsComment": bIsComment,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._a_args = kwargs["aArgs"]
        self._a_command = kwargs["aCommand"]
        self._a_target = kwargs["aTarget"]
        self._n_flags = kwargs["nFlags"]
        self._b_is_comment = kwargs["bIsComment"]


    @property
    def aArgs(self) -> typing.Tuple[PropertyValue_c9610c73, ...]:
        """
        specifies the dispatch command arguments
        
        That means the Arguments parameter of a corresponding XDispatch.dispatch() request.
        """
        return self._a_args

    @aArgs.setter
    def aArgs(self, value: typing.Tuple[PropertyValue_c9610c73, ...]) -> None:
        self._a_args = value

    @property
    def aCommand(self) -> str:
        """
        specifies the dispatch command
        
        That means the URL parameter of a corresponding XDispatchProvider.queryDispatch() request.
        """
        return self._a_command

    @aCommand.setter
    def aCommand(self, value: str) -> None:
        self._a_command = value

    @property
    def aTarget(self) -> str:
        """
        specifies the frame target
        
        That means the TargetFrameName parameter of a corresponding XDispatchProvider.queryDispatch() request.
        """
        return self._a_target

    @aTarget.setter
    def aTarget(self, value: str) -> None:
        self._a_target = value

    @property
    def nFlags(self) -> int:
        """
        specifies the optional search flags
        
        That means the SearchFlags parameter of a corresponding XDispatchProvider.queryDispatch() request.
        """
        return self._n_flags

    @nFlags.setter
    def nFlags(self, value: int) -> None:
        self._n_flags = value

    @property
    def bIsComment(self) -> bool:
        """
        specifies if this statement should be recorded as commented out or not
        """
        return self._b_is_comment

    @bIsComment.setter
    def bIsComment(self, value: bool) -> None:
        self._b_is_comment = value


__all__ = ['DispatchStatement']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbc


class DataType(object):
    """
    Const Class

    These constants are used to specify database data types which are used to identify the generic SQL types.
    
    The definition is based on JDBC 3.0.
    
    The actual type constant values are equivalent to those in the X/Open CLI.
    
    Precise information about the specific types can be got from XDatabaseMetaData.getTypeInfo().
    
    **since**
    
        OOo 2.0

    See Also:
        `API DataType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sdbc_1_1DataType.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbc'
    __ooo_full_ns__: str = 'com.sun.star.sdbc.DataType'
    __ooo_type_name__: str = 'const'

    BIT = -7
    TINYINT = -6
    SMALLINT = 5
    INTEGER = 4
    BIGINT = -5
    FLOAT = 6
    REAL = 7
    DOUBLE = 8
    NUMERIC = 2
    DECIMAL = 3
    CHAR = 1
    VARCHAR = 12
    LONGVARCHAR = -1
    DATE = 91
    TIME = 92
    TIMESTAMP = 93
    BINARY = -2
    VARBINARY = -3
    LONGVARBINARY = -4
    SQLNULL = 0
    OTHER = 1111
    """
    indicates that the SQL type is database-specific and gets mapped to an object that can be accessed via the method com.sun.star.sdbc.XRow.getObject().
    """
    OBJECT = 2000
    """
    indicates a type which is represented by an object which implements this type.
    """
    DISTINCT = 2001
    """
    describes a type based on a built-in type.
    
    It is a user-defined data type (UDT).
    """
    STRUCT = 2002
    """
    indicates a type consisting of attributes that may be any type.
    
    It is a user-defined data type (UDT).
    """
    ARRAY = 2003
    """
    indicates a type representing an SQL ARRAY.
    """
    BLOB = 2004
    """
    indicates a type representing an SQL Binary Large Object.
    """
    CLOB = 2005
    """
    indicates a type representing an SQL Character Large Object.
    """
    REF = 2006
    """
    indicates a type representing an SQL REF, a referencing type.
    """
    BOOLEAN = 16
    """
    identifies the generic SQL type BOOLEAN.
    
    **since**
    
        OOo 2.0
    """

__all__ = ['DataType']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class FillStyle(metaclass=UnoEnumMeta, type_name="com.sun.star.drawing.FillStyle", name_space="com.sun.star.drawing"):
        """Dynamically created class that represents ``com.sun.star.drawing.FillStyle`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.drawing.FillStyle import BITMAP as FILL_STYLE_BITMAP
        from com.sun.star.drawing.FillStyle import GRADIENT as FILL_STYLE_GRADIENT
        from com.sun.star.drawing.FillStyle import HATCH as FILL_STYLE_HATCH
        from com.sun.star.drawing.FillStyle import NONE as FILL_STYLE_NONE
        from com.sun.star.drawing.FillStyle import SOLID as FILL_STYLE_SOLID

        class FillStyle(uno.Enum):
            """
            Enum Class


            See Also:
                `API FillStyle <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing.html#a93450c852ea0dc97ffc5168069ed1bc0>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.drawing.FillStyle', value)

            __ooo_ns__: str = 'com.sun.star.drawing'
            __ooo_full_ns__: str = 'com.sun.star.drawing.FillStyle'
            __ooo_type_name__: str = 'enum'

            BITMAP = FILL_STYLE_BITMAP
            """
            use a bitmap to fill the area.
            """
            GRADIENT = FILL_STYLE_GRADIENT
            """
            use a gradient color to fill the area.
            """
            HATCH = FILL_STYLE_HATCH
            """
            use a hatch to fill the area.
            """
            NONE = FILL_STYLE_NONE
            """
            the area is not filled.

            The text size is only defined by the font properties.

            Don't animate this text.

            the line is hidden.

            the joint between lines will not be connected

            the line has no special end.
            """
            SOLID = FILL_STYLE_SOLID
            """
            use a solid color to fill the area.

            the line is solid.
            """
    else:
        # keep document generators happy
        from ...lo.drawing.fill_style import FillStyle as FillStyle


__all__ = ['FillStyle']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.xml
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class FastAttribute(object):
    """
    Struct Class

    A struct to keep information of an element's attribute.

    See Also:
        `API FastAttribute <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1xml_1_1FastAttribute.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml'
    __ooo_full_ns__: str = 'com.sun.star.xml.FastAttribute'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.xml.FastAttribute'
    """Literal Constant ``com.sun.star.xml.FastAttribute``"""

    def __init__(self, Token: typing.Optional[int] = 0, Value: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Token (int, optional): Token value.
            Value (str, optional): Value value.
        """
        super().__init__()

        if isinstance(Token, FastAttribute):
            oth: FastAttribute = Token
            self.Token = oth.Token
            self.Value = oth.Value
            return

        kargs = {
            "Token": Token,
            "Value": Value,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._token = kwargs["Token"]
        self._value = kwargs["Value"]


    @property
    def Token(self) -> int:
        """
        the token corresponding to the attribute
        """
        return self._token

    @Token.setter
    def Token(self, value: int) -> None:
        self._token = value

    @property
    def Value(self) -> str:
        """
        the attribute value
        """
        return self._value

    @Value.setter
    def Value(self, value: str) -> None:
        self._value = value


__all__ = ['FastAttribute']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.frame
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from .x_dispatch import XDispatch as XDispatch_98ff0a9b
    from .x_dispatch_recorder import XDispatchRecorder as XDispatchRecorder_fbd70dd1
    from ..util.url import URL as URL_57ad07b9

class XDispatchRecorderSupplier(XInterface_8f010a43):
    """
    provides access to the record mechanism of dispatches
    
    With a XDispatchRecorder it's possible to record calls of XDispatch.dispatch(). The recorded data (may a script) can be used to automate recorded dispatch and start it at later time again. This supplier provides access to the recorder and supports some functionality to work with the macro recording mechanism in an easy manner.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XDispatchRecorderSupplier <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XDispatchRecorderSupplier.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.XDispatchRecorderSupplier'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.frame.XDispatchRecorderSupplier'

    @abstractmethod
    def dispatchAndRecord(self, URL: URL_57ad07b9, Arguments: typing.Tuple[PropertyValue_c9610c73, ...], Dispatcher: XDispatch_98ff0a9b) -> None:
        """
        dispatch given URL and record it if recording is enabled
        
        Parameter Dispatcher is used internally to make the dispatch. If recording isn't enabled it will be a normal XDispatch.dispatch() call. Otherwise follow algorithm is used:
        """
        ...
    @abstractmethod
    def getDispatchRecorder(self) -> XDispatchRecorder_fbd70dd1:
        """
        provides access on the recorder of this supplier
        
        Returned recorder can be used to record dispatches manually or to get recorded data for further using e.g. saving. He is internally used too due to the method XDispatchRecorderSupplier.dispatchAndRecord().
        """
        ...
    @abstractmethod
    def setDispatchRecorder(self, Recorder: XDispatchRecorder_fbd70dd1) -> None:
        """
        set a dispatch recorder on this supplier
        
        Setting of a new recorder make it possible to change recording mode. May there can exist different implementations of a recorder (e.g. to generate Java, Basic or other formats). Changing between local recording inside one Frame or global one by using more than ones can be forced too.
        """
        ...

__all__ = ['XDispatchRecorderSupplier']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.frame
from __future__ import annotations
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XUIControllerRegistration(XInterface_8f010a43):
    """
    is used to query, register and unregister user interface controller.
    
    A user interface controller can be registered for a command URL. A certain user interface controller will be created when a user interface element contains a registered command URL.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XUIControllerRegistration <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XUIControllerRegistration.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.XUIControllerRegistration'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.frame.XUIControllerRegistration'

    @abstractmethod
    def deregisterController(self, aCommandURL: str, aModelName: str) -> None:
        """
        function to remove a previously defined association between a user interface controller implementation and a command URL and optional module.
        """
        ...
    @abstractmethod
    def hasController(self, aCommandURL: str, aModelName: str) -> bool:
        """
        function to check if an user interface controller is registered for a command URL and optional module.
        """
        ...
    @abstractmethod
    def registerController(self, aCommandURL: str, aModelName: str, aControllerImplementationName: str) -> None:
        """
        function to create an association between a user interface controller implementation and a command URL and optional module.
        """
        ...

__all__ = ['XUIControllerRegistration']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart
from __future__ import annotations
from abc import abstractproperty
from .chart_axis_x_supplier import ChartAxisXSupplier as ChartAxisXSupplier_a950e4d
from .x_two_axis_x_supplier import XTwoAxisXSupplier as XTwoAxisXSupplier_fcdb0ded

class ChartTwoAxisXSupplier(ChartAxisXSupplier_a950e4d, XTwoAxisXSupplier_fcdb0ded):
    """
    Service Class

    a helper service for chart documents which supply primary and secondary x-axes.
    
    **since**
    
        OOo 3.0

    See Also:
        `API ChartTwoAxisXSupplier <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart_1_1ChartTwoAxisXSupplier.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart'
    __ooo_full_ns__: str = 'com.sun.star.chart.ChartTwoAxisXSupplier'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def HasSecondaryXAxis(self) -> bool:
        """
        determines if the secondary x-axis is shown or hidden.
        """
        ...

    @abstractproperty
    def HasSecondaryXAxisDescription(self) -> bool:
        """
        determines for the secondary x-axis if the labels at the tick marks are shown or hidden.
        """
        ...

    @abstractproperty
    def HasSecondaryXAxisTitle(self) -> bool:
        """
        determines if the title of the secondary X-axis is shown or hidden.
        
        **since**
        
            OOo 3.0
        """
        ...


__all__ = ['ChartTwoAxisXSupplier']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.datatransfer
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class DataFlavor(object):
    """
    Struct Class

    Each instance represents the concept of a data format as it would appear on a clipboard, or during drag and drop.

    See Also:
        `API DataFlavor <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1datatransfer_1_1DataFlavor.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.datatransfer'
    __ooo_full_ns__: str = 'com.sun.star.datatransfer.DataFlavor'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.datatransfer.DataFlavor'
    """Literal Constant ``com.sun.star.datatransfer.DataFlavor``"""

    def __init__(self, MimeType: typing.Optional[str] = '', HumanPresentableName: typing.Optional[str] = '', DataType: typing.Optional[object] = None) -> None:
        """
        Constructor

        Arguments:
            MimeType (str, optional): MimeType value.
            HumanPresentableName (str, optional): HumanPresentableName value.
            DataType (object, optional): DataType value.
        """
        super().__init__()

        if isinstance(MimeType, DataFlavor):
            oth: DataFlavor = MimeType
            self.MimeType = oth.MimeType
            self.HumanPresentableName = oth.HumanPresentableName
            self.DataType = oth.DataType
            return

        kargs = {
            "MimeType": MimeType,
            "HumanPresentableName": HumanPresentableName,
            "DataType": DataType,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._mime_type = kwargs["MimeType"]
        self._human_presentable_name = kwargs["HumanPresentableName"]
        self._data_type = kwargs["DataType"]


    @property
    def MimeType(self) -> str:
        """
        The MIME content-type (type/subtype) string describing the data format of the object to transfer.
        
        MimeType must conform to Rfc2045 and Rfc2046)
        """
        return self._mime_type

    @MimeType.setter
    def MimeType(self, value: str) -> None:
        self._mime_type = value

    @property
    def HumanPresentableName(self) -> str:
        """
        A human presentable name for the data format.
        """
        return self._human_presentable_name

    @HumanPresentableName.setter
    def HumanPresentableName(self, value: str) -> None:
        self._human_presentable_name = value

    @property
    def DataType(self) -> object:
        """
        The type of the object to transfer, for example, XOutputStream.
        """
        return self._data_type

    @DataType.setter
    def DataType(self, value: object) -> None:
        self._data_type = value


__all__ = ['DataFlavor']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.report
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class Calculation(metaclass=UnoConstMeta, type_name="com.sun.star.report.Calculation", name_space="com.sun.star.report"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.report.Calculation``"""
        pass

    class CalculationEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.report.Calculation", name_space="com.sun.star.report"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.report.Calculation`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.report import Calculation as Calculation
    else:
        # keep document generators happy
        from ...lo.report.calculation import Calculation as Calculation

    class CalculationEnum(IntEnum):
        """
        Enum of Const Class Calculation

        Specifies how to calculate a value.
        """
        NONE = Calculation.NONE
        """
        returns the average of a field.
        """
        AVERAGE = Calculation.AVERAGE
        """
        returns the average of a field.
        """
        CORRELATION = Calculation.CORRELATION
        """
        returns the correlation of two fields.
        """
        COUNT = Calculation.COUNT
        """
        counts the number of values, from the field.
        """
        COVARIANCE = Calculation.COVARIANCE
        """
        returns the measure of the linear relation between paired variables.
        """
        DISTINCTCOUNT = Calculation.DISTINCTCOUNT
        """
        returns the number of none repeating values, from the field.
        """
        MAXIMUM = Calculation.MAXIMUM
        """
        returns the largest value from the field.
        """
        MEDIAN = Calculation.MEDIAN
        """
        returns the middle value in a sequence of numeric values.
        """
        MINIMUM = Calculation.MINIMUM
        """
        returns the smallest value from the field.
        """
        MODE = Calculation.MODE
        """
        returns the most frequently returning value from the field.
        """
        NTHLARGEST = Calculation.NTHLARGEST
        """
        returns the Nth largest value from the field.
        """
        NTHMOSTFREQUENT = Calculation.NTHMOSTFREQUENT
        """
        returns the Nth most commonly occurring value from the field.
        """
        NTHSMALLEST = Calculation.NTHSMALLEST
        """
        returns the Nth smallest value from the field.
        """
        PERCENTAGE = Calculation.PERCENTAGE
        """
        returns as a percentage of the grand total summary.
        """
        PERCENTILE = Calculation.PERCENTILE
        """
        returns the value for a specified percentile in a Number or Currency field.
        """
        POPSTANDARDDEVIATION = Calculation.POPSTANDARDDEVIATION
        """
        returns how much each value in the field deviate from the mean or average value for that field.
        """
        POPVARIANCE = Calculation.POPVARIANCE
        """
        returns the square of the standard deviation.
        """
        SAMPLESTANDARDDEVIATION = Calculation.SAMPLESTANDARDDEVIATION
        """
        returns the sample standard deviation for the field.
        """
        SAMPLEVARIANCE = Calculation.SAMPLEVARIANCE
        """
        returns the sample variance for the field.
        """
        SUM = Calculation.SUM
        """
        returns the total of all the values for the field.
        """
        WEIGHTEDAVG = Calculation.WEIGHTEDAVG
        """
        returns the weighted average for the field.
        """

__all__ = ['Calculation', 'CalculationEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ucb
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_content_identifier_mapping import XContentIdentifierMapping as XContentIdentifierMapping_56ef1044
    from .x_dynamic_result_set import XDynamicResultSet as XDynamicResultSet_e0360d0a

class XCachedDynamicResultSetFactory(XInterface_8f010a43):
    """
    creates a CachedDynamicResultSet.
    
    Pay attention to instantiate this helper on client side where your want to read the data respectively where you have instantiated the listener to the XDynamicResultSet.
    
    The needed stub on server side can be created using XCachedDynamicResultSetStubFactory.

    See Also:
        `API XCachedDynamicResultSetFactory <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ucb_1_1XCachedDynamicResultSetFactory.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.XCachedDynamicResultSetFactory'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.ucb.XCachedDynamicResultSetFactory'

    @abstractmethod
    def createCachedDynamicResultSet(self, SourceStub: XDynamicResultSet_e0360d0a, ContentIdentifierMapping: XContentIdentifierMapping_56ef1044) -> XDynamicResultSet_e0360d0a:
        """
        creates a remote optimizes XDynamicResultSet.
        """
        ...

__all__ = ['XCachedDynamicResultSetFactory']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.rendering
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class TextHit(object):
    """
    Struct Class

    This structure contains hit information for XTextLayout.
    
    This structure is used from the XTextLayout interface to transport information regarding hit tests.
    
    **since**
    
        OOo 2.0

    See Also:
        `API TextHit <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1rendering_1_1TextHit.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rendering'
    __ooo_full_ns__: str = 'com.sun.star.rendering.TextHit'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.rendering.TextHit'
    """Literal Constant ``com.sun.star.rendering.TextHit``"""

    def __init__(self, EntryIndex: typing.Optional[int] = 0, IsLeadingEdge: typing.Optional[bool] = False) -> None:
        """
        Constructor

        Arguments:
            EntryIndex (int, optional): EntryIndex value.
            IsLeadingEdge (bool, optional): IsLeadingEdge value.
        """
        super().__init__()

        if isinstance(EntryIndex, TextHit):
            oth: TextHit = EntryIndex
            self.EntryIndex = oth.EntryIndex
            self.IsLeadingEdge = oth.IsLeadingEdge
            return

        kargs = {
            "EntryIndex": EntryIndex,
            "IsLeadingEdge": IsLeadingEdge,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._entry_index = kwargs["EntryIndex"]
        self._is_leading_edge = kwargs["IsLeadingEdge"]


    @property
    def EntryIndex(self) -> int:
        """
        This contains the entry index.
        
        The entry index is the index of the insertion point in the character sequence. The insertion point denotes positions between the actual characters in the string, and can thus have values ranging from 0 up to the number of characters in the string. Hereby, an index of 0 denotes an insertion position before the first character, and an index containing the number of characters denotes an insertion behind the last character.
        """
        return self._entry_index

    @EntryIndex.setter
    def EntryIndex(self, value: int) -> None:
        self._entry_index = value

    @property
    def IsLeadingEdge(self) -> bool:
        """
        This member denotes whether the hit was on the leading edge.
        
        Each character is divided in two halves, the leading and the trailing part. The leading edge is the part of the glyph encountered first when reading text of the corresponding language (i.e. the leading edge of an Arabic glyph is the right half of it, whereas it is the left half of a Latin character). If the hit was on the leading edge, this member is set to TRUE.
        """
        return self._is_leading_edge

    @IsLeadingEdge.setter
    def IsLeadingEdge(self, value: bool) -> None:
        self._is_leading_edge = value


__all__ = ['TextHit']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet


class FilterOperator2(object):
    """
    Const Class

    specifies the type of a single condition in a filter descriptor.
    
    This constants group extends the FilterOperator enum by additional filter operators.
    
    **since**
    
        OOo 3.2

    See Also:
        `API FilterOperator2 <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet_1_1FilterOperator2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.FilterOperator2'
    __ooo_type_name__: str = 'const'

    EMPTY = 0
    """
    selects empty entries.
    """
    NOT_EMPTY = 1
    """
    selects non-empty entries.
    """
    EQUAL = 2
    """
    value has to be equal to the specified value.
    """
    NOT_EQUAL = 3
    """
    value must not be equal to the specified value.
    """
    GREATER = 4
    """
    value has to be greater than the specified value.
    """
    GREATER_EQUAL = 5
    """
    value has to be greater than or equal to the specified value.
    """
    LESS = 6
    """
    value has to be less than the specified value.
    """
    LESS_EQUAL = 7
    """
    value has to be less than or equal to the specified value.
    """
    TOP_VALUES = 8
    """
    selects a specified number of entries with the greatest values.
    """
    TOP_PERCENT = 9
    """
    selects a specified percentage of entries with the greatest values.
    """
    BOTTOM_VALUES = 10
    """
    selects a specified number of entries with the lowest values.
    """
    BOTTOM_PERCENT = 11
    """
    selects a specified percentage of entries with the lowest values.
    """
    CONTAINS = 12
    """
    selects contains entries.
    """
    DOES_NOT_CONTAIN = 13
    """
    selects does-not-contain entries.
    """
    BEGINS_WITH = 14
    """
    selects begins-with entries.
    """
    DOES_NOT_BEGIN_WITH = 15
    """
    selects does-not-begin-with entries.
    """
    ENDS_WITH = 16
    """
    selects ends-with entries.
    """
    DOES_NOT_END_WITH = 17
    """
    selects does-not-end-with entries.
    """

__all__ = ['FilterOperator2']
